@@ -24,7 +24,7 @@ from oslo_log import log
 from oslo_utils.secretutils import md5
 
 # Default cache expiration period
-CACHE_DURATION = 86400
+CACHE_DURATION = 600
 
 NAME_ENCODED = __name__.encode('utf-8')
 CACHE_NAMESPACE = uuid.UUID(
@@ -35,8 +35,9 @@ LOG = log.getLogger(__name__)
 
 
 class CacheClient(object):
-    def __init__(self, region):
+    def __init__(self, region, conf):
         self.region = region
+        self.conf = conf
 
     def get(self, key):
         value = self.region.get(key)
@@ -50,57 +51,59 @@ class CacheClient(object):
     def delete(self, key):
         return self.region.delete(key)
 
+    def resolve_uuid_from_cache(self, attr, uuid):
+        resource_name = self.get(uuid)
+        if resource_name:
+            return resource_name
+        else:
+            # Retrieve project and user names from Keystone only
+            # if ceilometer doesn't have a caching backend
+            resource_name = self._resolve_uuid_from_keystone(attr, uuid)
+            self.set(uuid, resource_name)
+            return resource_name
+
+    def _resolve_uuid_from_keystone(self, attr, uuid):
+        try:
+            return getattr(
+                keystone_client.get_client(self.conf), attr
+            ).get(uuid).name
+        except AttributeError as e:
+            LOG.warning("Found '%s' while resolving uuid %s to name", e, uuid)
+        except ka_exceptions.NotFound as e:
+            LOG.warning(e.message)
+
 
 def get_client(conf):
     cache.configure(conf)
-    if 'cache' in conf.keys() and conf.cache.enabled:
+    if conf.cache.enabled:
         region = get_cache_region(conf)
         if region:
-            return CacheClient(region)
+            return CacheClient(region, conf)
+    else:
+        # configure oslo_cache.dict backend if
+        # no caching backend is configured
+        region = get_dict_cache_region()
+        return CacheClient(region, conf)
+
+
+def get_dict_cache_region():
+    region = cache.create_region()
+    region.configure('oslo_cache.dict', expiration_time=CACHE_DURATION)
+    return region
 
 
 def get_cache_region(conf):
-    # Set expiration time to default CACHE_DURATION if missing in conf
-    if not conf.cache.expiration_time:
-        conf.cache.expiration_time = CACHE_DURATION
-
+    # configure caching region using params from config
     try:
         region = cache.create_region()
         cache.configure_cache_region(conf, region)
-        cache.key_mangler = cache_key_mangler
         return region
+
     except exception.ConfigurationError as e:
-        LOG.error("failed to configure oslo_cache. %s", str(e))
-        LOG.warning("using keystone to identify names from polled samples")
+        LOG.error("failed to configure oslo_cache: %s", str(e))
 
 
 def cache_key_mangler(key):
     """Construct an opaque cache key."""
 
     return uuid.uuid5(CACHE_NAMESPACE, key).hex
-
-
-def resolve_uuid_from_cache(conf, attr, uuid):
-    # empty cache_client means either caching is not enabled or
-    # there was an error configuring cache
-    cache_client = get_client(conf)
-    if cache_client:
-        resource_name = cache_client.get(uuid)
-        if resource_name:
-            return resource_name
-
-    # Retrieve project and user names from Keystone only
-    # if ceilometer doesn't have a caching backend
-    resource_name = resolve_uuid_from_keystone(conf, attr, uuid)
-    if cache_client:
-        cache_client.set(uuid, resource_name)
-    return resource_name
-
-
-def resolve_uuid_from_keystone(conf, attr, uuid):
-    try:
-        return getattr(keystone_client.get_client(conf), attr).get(uuid).name
-    except AttributeError as e:
-        LOG.warning("Found '%s' while resolving uuid %s to name", e, uuid)
-    except ka_exceptions.NotFound as e:
-        LOG.warning(e.message)
