@@ -21,9 +21,8 @@ import sys
 
 from oslo_config import cfg
 from oslo_utils import timeutils
-from stevedore import extension
 
-from ceilometer import pipeline
+from ceilometer.pipeline import sample as sample_pipe
 from ceilometer import sample
 from ceilometer import service
 
@@ -77,8 +76,7 @@ def send_sample():
     root_logger.addHandler(console)
     root_logger.setLevel(logging.DEBUG)
 
-    pipeline_manager = pipeline.setup_pipeline(
-        conf, extension.ExtensionManager('ceilometer.transformer'))
+    pipeline_manager = sample_pipe.SamplePipelineManager(conf)
 
     with pipeline_manager.publisher() as p:
         p([sample.Sample(
