@@ -16,6 +16,7 @@
 import collections
 import functools
 import sys
+import warnings
 
 from os_win import exceptions as os_win_exc
 from os_win import utilsfactory
@@ -82,6 +83,9 @@ class HyperVInspector(virt_inspector.Inspector):
         self._utils = utilsfactory.get_metricsutils()
         self._host_max_cpu_clock = self._compute_host_max_cpu_clock()
 
+        warnings.warn('Support for HyperV is deprecated.',
+                      category=DeprecationWarning, stacklevel=2)
+
     def _compute_host_max_cpu_clock(self):
         hostutils = utilsfactory.get_hostutils()
         # host's number of CPUs and CPU clock speed will not change.
