@@ -15,11 +15,10 @@
 
 import abc
 
-import six
 
-
-@six.add_metaclass(abc.ABCMeta)
-class Driver(object):
+class Driver(object, metaclass=abc.ABCMeta):
+    def __init__(self, conf):
+        self.conf = conf
 
     @abc.abstractmethod
     def get_sample_data(self, meter_name, parse_url, params, cache):
