@@ -27,54 +27,54 @@ from ceilometer import service
 from ceilometer.tests import base as tests_base
 
 TEST_NOTICE_CTXT = {
-    u'auth_token': u'3d8b13de1b7d499587dfc69b77dc09c2',
-    u'is_admin': True,
-    u'project_id': u'7c150a59fe714e6f9263774af9688f0e',
-    u'quota_class': None,
-    u'read_deleted': u'no',
-    u'remote_address': u'10.0.2.15',
-    u'request_id': u'req-d68b36e0-9233-467f-9afb-d81435d64d66',
-    u'roles': [u'admin'],
-    u'timestamp': u'2012-05-08T20:23:41.425105',
-    u'user_id': u'1e3ce043029547f1a61c1996d1a531a2',
+    'auth_token': '3d8b13de1b7d499587dfc69b77dc09c2',
+    'is_admin': True,
+    'project_id': '7c150a59fe714e6f9263774af9688f0e',
+    'quota_class': None,
+    'read_deleted': 'no',
+    'remote_address': '10.0.2.15',
+    'request_id': 'req-d68b36e0-9233-467f-9afb-d81435d64d66',
+    'roles': ['admin'],
+    'timestamp': '2012-05-08T20:23:41.425105',
+    'user_id': '1e3ce043029547f1a61c1996d1a531a2',
 }
 
 TEST_NOTICE_METADATA = {
-    u'message_id': u'dae6f69c-00e0-41c0-b371-41ec3b7f4451',
-    u'timestamp': u'2012-05-08 20:23:48.028195',
+    'message_id': 'dae6f69c-00e0-41c0-b371-41ec3b7f4451',
+    'timestamp': '2012-05-08 20:23:48.028195',
 }
 
 TEST_NOTICE_PAYLOAD = {
-    u'created_at': u'2012-05-08 20:23:41',
-    u'deleted_at': u'',
-    u'disk_gb': 0,
-    u'display_name': u'testme',
-    u'fixed_ips': [{u'address': u'10.0.0.2',
-                    u'floating_ips': [],
-                    u'meta': {},
-                    u'type': u'fixed',
-                    u'version': 4}],
-    u'image_ref_url': u'http://10.0.2.15:9292/images/UUID',
-    u'instance_id': u'9f9d01b9-4a58-4271-9e27-398b21ab20d1',
-    u'instance_type': u'm1.tiny',
-    u'instance_type_id': 2,
-    u'launched_at': u'2012-05-08 20:23:47.985999',
-    u'memory_mb': 512,
-    u'state': u'active',
-    u'state_description': u'',
-    u'tenant_id': u'7c150a59fe714e6f9263774af9688f0e',
-    u'user_id': u'1e3ce043029547f1a61c1996d1a531a2',
-    u'reservation_id': u'1e3ce043029547f1a61c1996d1a531a3',
-    u'vcpus': 1,
-    u'root_gb': 0,
-    u'ephemeral_gb': 0,
-    u'host': u'compute-host-name',
-    u'availability_zone': u'1e3ce043029547f1a61c1996d1a531a4',
-    u'os_type': u'linux?',
-    u'architecture': u'x86',
-    u'image_ref': u'UUID',
-    u'kernel_id': u'1e3ce043029547f1a61c1996d1a531a5',
-    u'ramdisk_id': u'1e3ce043029547f1a61c1996d1a531a6',
+    'created_at': '2012-05-08 20:23:41',
+    'deleted_at': '',
+    'disk_gb': 0,
+    'display_name': 'testme',
+    'fixed_ips': [{'address': '10.0.0.2',
+                    'floating_ips': [],
+                    'meta': {},
+                    'type': 'fixed',
+                    'version': 4}],
+    'image_ref_url': 'http://10.0.2.15:9292/images/UUID',
+    'instance_id': '9f9d01b9-4a58-4271-9e27-398b21ab20d1',
+    'instance_type': 'm1.tiny',
+    'instance_type_id': 2,
+    'launched_at': '2012-05-08 20:23:47.985999',
+    'memory_mb': 512,
+    'state': 'active',
+    'state_description': '',
+    'tenant_id': '7c150a59fe714e6f9263774af9688f0e',
+    'user_id': '1e3ce043029547f1a61c1996d1a531a2',
+    'reservation_id': '1e3ce043029547f1a61c1996d1a531a3',
+    'vcpus': 1,
+    'root_gb': 0,
+    'ephemeral_gb': 0,
+    'host': 'compute-host-name',
+    'availability_zone': '1e3ce043029547f1a61c1996d1a531a4',
+    'os_type': 'linux?',
+    'architecture': 'x86',
+    'image_ref': 'UUID',
+    'kernel_id': '1e3ce043029547f1a61c1996d1a531a5',
+    'ramdisk_id': '1e3ce043029547f1a61c1996d1a531a6',
 }
 
 
