@@ -39,13 +39,13 @@ class TestSample(base.BaseTestCase):
 
     def test_sample_from_notifications_list(self):
         msg = {
-            'event_type': u'sample.create',
+            'event_type': 'sample.create',
             'metadata': {
-                'timestamp': u'2015-06-19T09:19:35.786893',
-                'message_id': u'939823de-c242-45a2-a399-083f4d6a8c3e'},
-            'payload': [{u'counter_name': u'instance100'}],
+                'timestamp': '2015-06-19T09:19:35.786893',
+                'message_id': '939823de-c242-45a2-a399-083f4d6a8c3e'},
+            'payload': [{'counter_name': 'instance100'}],
             'priority': 'info',
-            'publisher_id': u'ceilometer.api',
+            'publisher_id': 'ceilometer.api',
         }
         s = sample.Sample.from_notification(
             'sample', 'type', 1.0, '%', 'user', 'project', 'res', msg)
@@ -55,13 +55,13 @@ class TestSample(base.BaseTestCase):
 
     def test_sample_from_notifications_dict(self):
         msg = {
-            'event_type': u'sample.create',
+            'event_type': 'sample.create',
             'metadata': {
-                'timestamp': u'2015-06-19T09:19:35.786893',
-                'message_id': u'939823de-c242-45a2-a399-083f4d6a8c3e'},
-            'payload': {u'counter_name': u'instance100'},
+                'timestamp': '2015-06-19T09:19:35.786893',
+                'message_id': '939823de-c242-45a2-a399-083f4d6a8c3e'},
+            'payload': {'counter_name': 'instance100'},
             'priority': 'info',
-            'publisher_id': u'ceilometer.api',
+            'publisher_id': 'ceilometer.api',
         }
         s = sample.Sample.from_notification(
             'sample', 'type', 1.0, '%', 'user', 'project', 'res', msg)
@@ -71,13 +71,13 @@ class TestSample(base.BaseTestCase):
 
     def test_sample_from_notifications_assume_utc(self):
         msg = {
-            'event_type': u'sample.create',
+            'event_type': 'sample.create',
             'metadata': {
-                'timestamp': u'2015-06-19T09:19:35.786893',
-                'message_id': u'939823de-c242-45a2-a399-083f4d6a8c3e'},
-            'payload': {u'counter_name': u'instance100'},
+                'timestamp': '2015-06-19T09:19:35.786893',
+                'message_id': '939823de-c242-45a2-a399-083f4d6a8c3e'},
+            'payload': {'counter_name': 'instance100'},
             'priority': 'info',
-            'publisher_id': u'ceilometer.api',
+            'publisher_id': 'ceilometer.api',
         }
         s = sample.Sample.from_notification(
             'sample', 'type', 1.0, '%', 'user', 'project', 'res', msg)
@@ -85,13 +85,13 @@ class TestSample(base.BaseTestCase):
 
     def test_sample_from_notifications_keep_tz(self):
         msg = {
-            'event_type': u'sample.create',
+            'event_type': 'sample.create',
             'metadata': {
-                'timestamp': u'2015-06-19T09:19:35.786893+01:00',
-                'message_id': u'939823de-c242-45a2-a399-083f4d6a8c3e'},
-            'payload': {u'counter_name': u'instance100'},
+                'timestamp': '2015-06-19T09:19:35.786893+01:00',
+                'message_id': '939823de-c242-45a2-a399-083f4d6a8c3e'},
+            'payload': {'counter_name': 'instance100'},
             'priority': 'info',
-            'publisher_id': u'ceilometer.api',
+            'publisher_id': 'ceilometer.api',
         }
         s = sample.Sample.from_notification(
             'sample', 'type', 1.0, '%', 'user', 'project', 'res', msg)
